#
# spec file for package python3-ec2uploadimg
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define upstream_name ec2uploadimg
Name:           python3-ec2uploadimg
Version:        5.0.1
Release:        lp152.4.2
Summary:        Upload an image to EC2
License:        GPL-3.0+
Group:          System/Management
Url:            https://github.com/SUSE/Enceladus
Source0:        %{upstream_name}-%{version}.tar.bz2
Patch1:         proper-subnet-use.diff
Patch2:         enforce-architecture.patch
Requires:       python-ec2utilsbase < 4.0.0
Requires:       python-ec2utilsbase >= 3.0.0
Requires:       python3
Requires:       python3-boto3        >= 1.4.1
Requires:       python3-paramiko
BuildRequires:  python3-setuptools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

# Package renamed in SLE 12, do not remove Provides, Obsolete directives
# until after SLE 12 EOL
Provides:       python-ec2uploadimg = %{version}
Obsoletes:      python-ec2uploadimg < %{version}

%description
Upload a compressed .raw disk image to Amazon EC2 and create a snapshot
or register and AMI.

%prep
%setup -q -n %{upstream_name}-%{version}
%patch1 -p1
%patch2

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
install -d -m 755 %{buildroot}/%{_mandir}/man1
install -m 644 man/man1/ec2uploadimg.1 %{buildroot}/%{_mandir}/man1
gzip %{buildroot}/%{_mandir}/man1/ec2uploadimg.1

%files
%defattr(-,root,root,-)
%doc LICENSE
%{_mandir}/man*/*
%dir %{python3_sitelib}/ec2utils
%{python3_sitelib}/*
%{_bindir}/*

%changelog
* Wed Dec 19 2018 Robert Schweikert <rjschwei@suse.com>
- Add enforce-architecture.patch (bsc#1118027)
  + Support ARM architecture
- Add proper-subnet-use.diff
  + Use the proper subnet if no default subnet exists in the account
* Tue Sep 12 2017 rjschwei@suse.com
- Update to version 5.0.1
  + Add support for billing code addition during registration
    ~ Introduces incompatibility in API
  + Read VPC subnet information from ec2utils.conf
* Thu Aug 10 2017 rjschwei@suse.com
- Update to version 4.0.0
  + Convert to Python 3
* Thu Jan  5 2017 jgleissner@suse.com
- Update to version 3.0.2
  + fix use running instance as helper
* Tue Jan  3 2017 rjschwei@suse.com
- Update to version 3.0.1 (bsc#1007793)
  + Use block device map info from helper instance
  + Support new command line argument --instance-id to designate a
    running instance as the helper instance. Brings incompatible
    change of the uploader c-tor
* Sat Nov  5 2016 jengelh@inai.de
- Orthography fix in description.
* Wed Oct 26 2016 rjschwei@suse.com
- Update to version 2.0.0 (bsc#1007084)
  + Add --ena-support command line argument to enable ENA device support
  + Incompatible change, argument order for uploader class
* Thu Sep 15 2016 rjschwei@suse.com
- Update to version 1.1.3 (bsc#999019)
  + Support use of uploading without --verbose option
- From 1.1.2
  + Fix install from source by properly setting up a namespace
* Fri Jun 17 2016 rjschwei@suse.com
- Update to version 1.1.1 (bsc#981224)
  + Only pass relevant arguments to the registration API
* Mon Apr 11 2016 rjschwei@suse.com
- Update to version 1.1.0 (bsc#972845)
  + Allow the specification of security groups to use for the helper instance
  + Support the use of the private IP of the helper instance for image
    uploading
  + Add command line option to launch the helper instance into a
    specific VPC
  + Add consistency check. When using root swap the image used to
    launch the helper instance must be of the same virtualization type
    as the target image
* Fri Apr  8 2016 rjschwei@suse.com
- Update to version 1.0.0
  + Convert to use boto3
  + Incompatible changes
    ~ Remove --timeout command line option
    ~ Add --ssh-timeout command line option
    ~ Add --wait-count command line option
* Thu Feb 18 2016 rjschwei@suse.com
- Update to version 0.7.2 (bsc#966958)
  + Add error condition if uniqueness requirement is not met on command line
    ~ One region only if ami id or boot kernel are specified
  + Change code to accommodate changes in base utils for get_from_config(
* Mon Jan  4 2016 rjschwei@suse.com
- Add python-paramio as dependency (bsc#960585)
* Fri Nov 20 2015 rjschwei@suse.com
- Fix typo in package description (bsc#955993)
* Fri Nov 13 2015 rjschwei@suse.com
- Update to version 0.7.1 (bnc#954990)
  + Check that the specified account can be found in the config file
    provide error message if the account is not found
* Thu Aug 13 2015 rjschwei@suse.com
- Include in SLE 12 (FATE#319357)
* Tue Jul 14 2015 rjschwei@suse.com
- Update to version 0.7.0
  + Fix logic error in unsetting the bootkernel for HVM images
* Wed Jul  1 2015 rjschwei@suse.com
- Update to version 0.6.0
  + Fix issue #41, detach the storage volume prior to AMI creation
    or it will be carried forward to the new AMI
* Fri Jun 26 2015 rjschwei@suse.com
- Update to version 0.5.0
  + Fix issue #37, properly handle the unpack of a tarball
* Wed Jun 24 2015 rjschwei@suse.com
- Update to version 0.4.0
  + Support creation of image using root volume swap
  + Support customization of root volume size
  + Fix packaging issue on SLE 11
  + Properly print progress indicators during source upload
  + Properly handle tarball that only contains the image file
* Tue Jun 16 2015 rjschwei@suse.com
- Update tarball, contains fix for boot issue. The new source,
  no version bump, fixes an issue with image root volume creation.
  Theimages produced with the new version boot in Ec2.
* Fri Jun 12 2015 rjschwei@suse.com
- Initial build version 0.2.0
